@@ -7,9 +7,7 @@ from pxr.Usdviewq.plugin import PluginContainer
 
 from PySide2 import QtWidgets
 
-from . import sheets as _sheets
-from . import description as _description
-from . import create as _create
+from . import sheets as _sheets, description as _description, create as _create
 
 
 def _stage_on_widget(widget_creator):
@@ -66,9 +64,10 @@ class GrillPlugin(PluginContainer):
             _menu_item(title, launcher)
             for (title, launcher) in (
                 ("Create Assets", _stage_on_widget(_create.CreateAssets)),
+                ("Taxonomy Editor", _stage_on_widget(_create.TaxonomyEditor)),
                 ("Spreadsheet Editor", _stage_on_widget(_sheets.SpreadsheetEditor)),
                 ("Prim Composition", prim_composition),
-                ("Layer Stack Composition", _stage_on_widget(_description.LayersComposition)),
+                ("LayerStack Composition", _stage_on_widget(_description.LayerStackComposition)),
                 ("Save Changes", save_changes),
             )
         ]
